// src/components/SignUp.tsx

import React, { useState, ChangeEvent, FormEvent } from 'react';
import { TextField, Button, Container, Typography, Box } from '@mui/material';
import axios, { AxiosResponse } from 'axios';
import { SignUpFormData, ApiResponse } from '../../types/auth';
import axiosInstance from '../../http/axiosInstance';

const SignUp: React.FC = () => {
    const [formData, setFormData] = useState<SignUpFormData>({
        email: '',
        login: '',
        phone: '',
        name: '',
        surname: '',
        is_active: true,
        password: '',
    });

    const handleChange = (e: ChangeEvent<HTMLInputElement>) => {
        setFormData({
            ...formData,
            [e.target.name]: e.target.value,
        });
    };

    const handleSubmit = async (e: FormEvent) => {
        e.preventDefault();
        try {
            const response: AxiosResponse<ApiResponse> = await axiosInstance.post(`${import.meta.env.VITE_API_AUTH_URL}/auth/user`, formData);
            console.log('Успешная регистрация:', response.data);
        } catch (error) {
            console.error('Ошибка регистрации:', error);
        }
    };

    return (
        <Container maxWidth="sm">
            <Box my={4}>
                <Typography variant="h4" component="h1" gutterBottom>
                    Регистрация
                </Typography>
                <form onSubmit={handleSubmit}>
                    <TextField
                        fullWidth
                        margin="normal"
                        name="email"
                        label="Email"
                        value={formData.email}
                        onChange={handleChange}
                        required
                    />
                    <TextField
                        fullWidth
                        margin="normal"
                        name="login"
                        label="Логин"
                        value={formData.login}
                        onChange={handleChange}
                        required
                    />
                    <TextField
                        fullWidth
                        margin="normal"
                        name="phone"
                        label="Телефон"
                        value={formData.phone}
                        onChange={handleChange}
                    />
                    <TextField
                        fullWidth
                        margin="normal"
                        name="name"
                        label="Имя"
                        value={formData.name}
                        onChange={handleChange}
                    />
                    <TextField
                        fullWidth
                        margin="normal"
                        name="surname"
                        label="Фамилия"
                        value={formData.surname}
                        onChange={handleChange}
                    />
                    <TextField
                        fullWidth
                        margin="normal"
                        type="password"
                        name="password"
                        label="Пароль"
                        value={formData.password}
                        onChange={handleChange}
                        required
                    />
                    <Button type="submit" variant="contained" color="primary">
                        Зарегистрироваться
                    </Button>
                </form>
            </Box>
        </Container>
    );
};

export default SignUp;